#!/bin/bash

#
# dnsbl-check-standalone.sh
#
# By Damon Tajeddini (dta)
# # 10.03.2009 , heise
# 
# als nagios-plugin rbe Sep. 2009
# geandert Juni 2011, rbe
#


LANG=C

true ${DNSBL_FILE:=/etc/dnsbl.list}
. /usr/lib/nagios/plugins/utils.sh

# reverse IP address bytes
convertIP()
{
 set `IFS=".";echo $1`
 echo $4.$3.$2.$1
}

usage()
{
 echo "Usage: $0 [-H host|-t]"
 echo " -H IP address to check"
 echo " -N FQDName to check"
 echo " -t check for timeouts"
 exit 3
}

# Checks the IP with list of DNSBL servers
check()
{
 ret_value=$STATE_OK
 blacklisted=""
 while read bl code; do
   [[ -z $bl || $bl == \#* ]] && continue
   [ -z $code ] && code='.*'
   #if dig $ip_arpa.$bl +short | grep -q "^127.0.0.$code$"
   dig_val="`dig $ip_arpa.$bl +short 2>&1`"
   case $? in
   10)
      echo $dig_val
      exit $STATE_CRITICAL
   ;;
   esac
   if [[ "$dig_val" =~ ^127.0.0.$code$ ]]
   then
     ret_value=$STATE_CRITICAL
     blacklisted+="$bl, "
   fi
 done < $DNSBL_FILE

 blacklisted=${blacklisted%, }
 if [ "$ret_value" = "$STATE_OK" ]; then 
   echo  "DNSBL OK for $ip" 
 else
   echo  "$ip blacklisted on: $blacklisted"
 fi
 exit $ret_value
} # check

check_timeout () {
 to_listed=''
 while read bl code; do
   [[ -z $bl || $bl == \#* ]] && continue
   if dig $ip_arpa.$bl +short | grep -q 'connection timed out'
   then
     to_listed+="$bl, "
   fi
 done < $DNSBL_FILE
 if [ -n "$to_listed" ]; then
   echo "query $ip timed out for: $to_listed"
 else
   echo "no blacklist query timed out"
 fi
}


cat $DNSBL_FILE 2>&1 1>/dev/null || exit $STATE_CRITICAL

case "$1" in
 -H)
 if [ -z "$2" ]; then
   echo "ip address missing"
   exit $STATE_UNKNOWN
 fi
 ip=$2
 ip_arpa=`convertIP $ip`
 check
 ;;

 -N)
    if [ -z "$2" ]; then
      echo "FQDN missing"
      exit $STATE_UNKNOWN
    fi
    ips=`dig $2 +short`
    if [ -z "$ips" ]; then
       echo "$2 not resolvable"
       exit $STATE_UNKNOWN
    fi 
    status=$STATE_OK
    message=''
    for ip in $ips; do
      ip_arpa=`convertIP $ip`
      message+="`check` -- "  || status=$STATE_CRITICAL
    done
    echo ${message%--*}
    exit $status
 ;;

 -t)
 # check for timeout
  ip='127.0.0.2'
  ip_arpa=`convertIP $ip`
  check_timeout
 ;;

 --help)
 usage
 exit
 ;;

 *)
 if [ -z "$1" ]; then
 usage
 fi
 echo "unknown command: $1"
 exit $STATE_UNKNOWN
 ;;
esac
