#!/bin/bash
# Author: Frederico Argolo
# Date: 2009-04-16

# check for last sucessful Backup of a bacula-job
# date 2012-02-21, jsc lihas@lihas.de

VERSION="v1.4"

# Variaveis reservadas ao Nagios:
STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
LANG=C
DEPS="mysql-client or postgresql-client-common"


rcfile="/etc/nagios-plugins/config/check_bacula.conf"
if [ ! -f "$rcfile" ]
then
cat << EOF > $rcfile
#bacula sql 
TYPE=mysql # psql
DATABASE=bacula
USER=bacula
PW=secret
EOF
fi

usage ()
{
   echo "check_bacula.sh $VERSION (Nagios plugin), depends on $DEPS

Usage: check_bacula.sh -j <job> -g <GracePeriod in seconds>

Options:
-j <job>		Check last backup for this job
-g seconds		critical if older than <seconds>
"
   exit $STATE_UNKNOWN
}

if [ "$(md5sum $rcfile)" = "87f351224961ddc36f395de39e32c567  $rcfile" ]
then
	msg=$(echo "Edit mysql-settings in $rcfile! This check depends on $DEPS")
        echo -e $msg
	usage;
fi

source $rcfile

# Date in Seconds
DATE=$(date +%s)

if [ $# -eq 0 ]; then
        usage;
fi

# Checando as opcoes definidas pelo usuario:
while [ $# -ne 0 ]
do
   case "$1" in
      -j)
	shift
      CLIENT=$1
      ;;
      -g)
      shift
	CRITICAL=$1
      ;;
      *)
      usage
      ;;
   esac
   shift
done

if [ -z "$CLIENT" ]; then
        echo "ERROR: You must specify client!"
        usage;
fi
if [ -z "$CRITICAL" ]; then
        echo "ERROR: You must specify the GracePeriod!"
        usage;
fi
if [ -z "$TYPE" ]; then
        echo "ERROR: You must specify the sql-Type in $rcfile, mysql or psql!"
        usage;
fi


#JOBSTATUS=$(mysql -u $USER -p$PW $DATABASE -B --skip-column-names -e "select JobStatus from Job where SchedTime like '${DATE}%' and Name like '${CLIENT}%' order by SchedTime DESC limit 1;")
#JOBSTATUSLONG=$(mysql -u $USER -p$PW $DATABASE -B --skip-column-names -e "select JobStatusLong from Status where JobStatus='$JOBSTATUS'";)



#
case $TYPE in
       mysql) LAST_SUCCESSFUL=$(mysql -u $USER -p$PW $DATABASE -B --skip-column-names -e "select JobTDate from Job where Name like '$CLIENT' and JobStatus like 'T' order by SchedTime DESC limit 1;" ) ;;
       #psql) LAST_SUCCESSFUL=$( su - $USER -s /bin/bash -c "psql -d $DATABASE -c \"select JobTDate from Job where Name like '$CLIENT' and JobStatus like 'T' order by SchedTime DESC limit 1 | grep ^'\ ' | grep -v jobtdate \"" ) ;;
       psql) LAST_SUCCESSFUL=$( su - $USER -s /bin/bash -c "psql -d $DATABASE -c \"select JobTDate from Job where Name like '$CLIENT' and JobStatus like 'T' order by SchedTime DESC limit 1;  \" | grep -v ^'----' | grep -v ^'('  | grep -v jobtdate | sed 's/ //' ") ;;
esac


if [ -z "$LAST_SUCCESSFUL" ]; then
        echo "<${CLIENT}> not found to be a job in bacula mysql-db/psql, or wrong sql-settings in $rcfile! This Nagios-check depends on $DEPS"
        usage;
fi

case $TYPE in
       mysql) LAST_BAD_STATE=$(mysql -u $USER -p$PW $DATABASE -B --skip-column-names -e "select JobTDate from Job where Name like '$CLIENT' and JobStatus not like 'T' order by SchedTime DESC limit 1;" );;
       psql) LAST_BAD_STATE=$( su - $USER -s /bin/bash -c "psql -d $DATABASE -c \"select JobTDate from Job where Name like '$CLIENT' and JobStatus not like 'T' order by SchedTime DESC limit 1;\" | grep -v ^'----' | grep -v ^'('  | grep -v jobtdate | sed 's/ //' " ) ;;
esac

msg=$(echo "last successful $(date -d@$LAST_SUCCESSFUL)")
if [ -n "$LAST_BAD_STATE" -a "$LAST_SUCCESSFUL" != "$LAST_BAD_STATE" ]
then
	msg=$(echo "last successful $(date -d @$LAST_SUCCESSFUL); last not successful $(date -d @$LAST_BAD_STATE)")
fi


if [ $LAST_SUCCESSFUL -gt $( echo "$DATE - $CRITICAL" | bc ) ] ; then
        echo -e $msg
        exit $STATE_OK;
else 
        echo -e $msg
        exit $STATE_CRITICAL;
fi

usage
