#!/bin/bash
# Author: Johannes Schoepfer
# date 2012-02-21, lihas@lihas.de

# check for empty tapes for bacula

VERSION="v0.9"

STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
LANG=C
DEPS="mysql-client"


rcfile="/etc/nagios-plugins/config/check_bacula.conf"
if [ ! -f "$rcfile" ]
then
cat << EOF > $rcfile
#bacula mysql 
DATABASE=bacula
USER=bacula
PW=secret
EOF
fi

usage ()
{
	cat << EOF
check_bacula_tapes.sh $VERSION (Nagios plugin), depends on $DEPS

Usage: $0 -w <tapes> -c <critical>

Options:
-w <tapes>		warning if less than <tapes> are appendable
-c <tapes>		critical if less than <tapes> are appendable
EOF

   exit $STATE_UNKNOWN
}

if [ "$(md5sum $rcfile)" = "87f351224961ddc36f395de39e32c567  $rcfile" ]
then
	msg=$(echo "Edit mysql-settings in $rcfile! This check depends on $DEPS")
        echo -e $msg
	usage;
fi

source $rcfile

# Date in Seconds
DATE=$(date +%s)

if [ $# -eq 0 ]; then
        usage;
fi

while [ $# -ne 0 ]
do
   case "$1" in
      -w)
	shift
	WARNING=$1
      ;;
      -c)
	shift
	CRITICAL=$1
      ;;
      *)
      usage
      ;;
   esac
   shift
done

if [ -z "$WARNING" ]; then
        echo "ERROR: You must specify -w !"
        usage;
fi
if [ -z "$CRITICAL" ]; then
        echo "ERROR: You must specify -c!"
        usage;
fi

TAPES_APPENDABLE=$(mysql -u $USER -p$PW $DATABASE -B --skip-column-names -e "select count(*) from Media where Slot != 0 AND VolStatus = 'Append' AND PoolId IN (SELECT PoolId FROM Pool WHERE Name='Default'); ")

if [ -z "$TAPES_APPENDABLE" ]; then
        echo "No ${TAPES} were found bacula mysql-db, or wrong mysql-settings in $rcfile! This check depends on $DEPS"
        usage;
fi

msg=$(echo "Appendable tapes: $TAPES_APPENDABLE")
echo -e $msg

if [ $TAPES_APPENDABLE -gt $WARNING ] ; then
        exit $STATE_OK;
elif [ $TAPES_APPENDABLE -gt $CRITICAL ] ; then
        exit $STATE_WARNING;
else 
        exit $STATE_CRITICAL;
fi

usage
