#! /bin/bash

#export LANG=C

set -u

WARNDAYS=1
CRITDAYS=2

DAR_STATUS_PATTERN_OK='0|11'
DAR_STATUS_PATTERN_WARNING='-'

VERBOSE=false
status=""

DAR_BACKUP_LIHAS="/usr/bin/dar-backup.sh"

# Nagios return codes
STATE_OK=0
STATE_WARNING=1
STATE_CRITICAL=2
STATE_UNKNOWN=3
STATE_DEPENDENT=4


while (($# > 0)); do
	case "$1" in
	-w)	shift; WARNDAYS=$1
	;;
	-c)	shift; CRITDAYS=$1
	;;
	-v)	VERBOSE=true
	;;
	*)	echo 'unkown option'
		exit $STATE_CRITICAL
	esac
	shift
done

if [ "$WARNDAYS" -gt "$CRITDAYS" ] ; then
	echo "WARNDAYS greater than CRITDAYS"
	exit $STATE_CRITICAL
fi

p=`pidof -o $$ -x $0`
if [ -n "$p" ]; then
        echo "another process 'check_darbackup.sh' (pid $p) is running"
        exit $STATE_WARNING
fi

#if [ -e /etc/dar-backup/dar-backup.conf ]; then
# . /etc/dar-backup/dar-backup.conf
# if [ -e /etc/dar-backup/dar-exclude.conf ]; then
#  . /etc/dar-backup/dar-exclude.conf
# fi
#elif [ -e /etc/backup-full.conf ]; then
# . /etc/backup-full.conf
#else
# echo "No config file found for $0" >2
# exit $STATE_CRITICAL
#fi


dar_status_explain () {

	if  [ -z "$1"  ] ; then
		echo 'bad'
	elif  echo "$1" | egrep -q "^($DAR_STATUS_PATTERN_OK)$"  ; then
		echo 'good'
	elif  echo "$1" | egrep -q "^($DAR_STATUS_PATTERN_WARNING)$"  ; then
		echo 'dont know'
	else
		echo 'bad'
	fi
}


statefile=/var/log/darbackup.status
if ! [ -f "$statefile" ]; then
        echo "$statefile not found"
        exit $STATE_CRITICAL
fi

statefile_version=`grep ^VERSION $statefile | cut -f2`


#lastgoodstate=`cut -f3 "$statefile" | egrep -n "^($DAR_STATUS_PATTERN_OK)$"   | cut -d: -f1 | tail -1`
lastgoodstate=`cut -f4 "$statefile" | grep -n "^good$"   | cut -d: -f1 | tail -1`
if [ -z "$lastgoodstate" ]; then
	echo "no good backup  found, `pidof -x $DAR_BACKUP_LIHAS >/dev/null && echo running || echo not running`"
	status=$STATE_CRITICAL
else
	lastgoodbackup=`sed -n "${lastgoodstate}p"  $statefile`
	if [ -z "$statefile_version" ]; then
		lastgoodtime=`echo "$lastgoodbackup" | cut -f4`
	else
		lastgoodtime=`echo "$lastgoodbackup" | cut -f5`
	fi
	lastgoodtime_s=`date -d "$lastgoodtime" +%s`
	now=`date +%s`
	
	#echo -n "last good backup ($lastgoodtime)"
	echo -n "last good backup `echo "$lastgoodbackup" | cut -f2` "
	if [ $((now-lastgoodtime_s)) -gt $((CRITDAYS*3600*24+3600*2)) ]; then
		echo -n " is older than $CRITDAYS days"
		status=$STATE_CRITICAL
	elif [ $((now-lastgoodtime_s)) -gt $((WARNDAYS*3600*24+3600*2)) ]; then
		echo -n " is older than $WARNDAYS days"
		status=$STATE_WARNING
	else
		status=$STATE_OK
	fi
	#echo ", endtime $lastgoodtime, dar-status: `echo "$lastgoodbackup" | cut -f3`"
	lastdu=`echo "$lastgoodbackup" | cut -f1`
	echo " ($lastdu, endtime: $lastgoodtime), `pidof -x $DAR_BACKUP_LIHAS >/dev/null && echo running || echo not running`"
fi

zeilenanzahl () {
	if [ -f "$1" ] ; then
		echo -n `wc -l "$1" | cut -d' ' -f1`
	else
		echo -n 0
		return 1
	fi
}

if $VERBOSE ; then
	tail -n 10 $statefile | 
	while IFS=$'\t' read disk_usage bckdir st st_long datum; do
		[ "$disk_usage" = VERSION ] && continue
		echo -n "$bckdir: $disk_usage dar-status: $st"
		#echo " (`dar_status_explain "$st"`)"
		echo " ($st_long)"
	done 
	rest=$((`zeilenanzahl $statefile` - 11))
	if [ $rest -gt 0 ]; then
		echo 
		echo "$rest more backups exist"
	fi
fi

exit $status

