#! /bin/bash

# nagios-plugin, das die Groesse von mehreren Verzeichnissen ueberwacht
# Verzeichnissgroessen nur ungefaehr
# Roland Becker <lihas@lihas.de>, Nov. 2012

set -u
export LC_ALL=C

CRITSIZE_u=2G
WARNSIZE_u=1G
#DIR_FILE="/usr/lib/nagios/plugins/lihas/`basename $0 .sh`.files"
DIR_FILE=""
DIRS=""

if [ -f  `dirname $0`/../utils.sh ]; then 
	. `dirname $0`/../utils.sh
else
	STATE_OK=0
	STATE_WARNING=1
	STATE_CRITICAL=2
	STATE_UNKNOWN=3
	STATE_DEPENDENT=4
fi


usage () {
	echo "usage: `basename $0` [ -c size[K|M|G]] [ -w size[K|G|M]] {-f filename | -d directory ..}"
	echo "directories must have no blanks"
	exit $STATE_UNKNOWN
}

ERRORFILE=$(mktemp -t `basename $0 .sh`.err-XXXX) || exit $STATE_CRITICAL
trap "{ rm -f $ERRORFILE; }" EXIT

while [ $# -gt 0 ]; do
	case "$1" in
		-c)	shift
			CRITSIZE_u=$1
		;;
		-w) shift
			WARNSIZE_u=$1
		;;
		-f) shift
			DIR_FILE=$1
		;;
		-d) shift
			DIRS="$*"
			break
		;;
		*) usage
	esac
	shift
done 

critdirs=""
warndirs=""
if [ -n "$DIR_FILE" ] ; then
	if [ -r "$DIR_FILE" ] ; then
		DIRS=`cat $DIR_FILE | grep -v '^#'`
	else
		echo "$DIR_FILE not readable"
		exit $STATE_UNKNOWN
	fi
fi
if [ -z "$DIRS" ]; then
	echo "no directorys specified"
	exit $STATE_UNKNOWN
fi

convert_unit_val () {
	local v=$1
	#echo "${!v}" | grep -q '[0-9]*\.[0-9][KMGT]' || return 1
	case "${v}" in
		*K) echo "${v%K}*1024" | bc | sed 's/\..*//'
		;;
		*M) echo "${v%M}*1024^2" | bc | sed 's/\..*//'
		;;
		*G) echo "${v%G}*1024^3" | bc | sed 's/\..*//'
		;;
		*T) echo "${v%T}*1024^4" | bc | sed 's/\..*//'
		;;
		*)  echo ${v}
	esac
}
CRITSIZE=`convert_unit_val $CRITSIZE_u`
WARNSIZE=`convert_unit_val $WARNSIZE_u`

while read size_u name; do
	size=`convert_unit_val $size_u`
	#if (($size==0)) ; then
	#	echo "size 0 for $name"
	#	exit $STATE_UNKNOWN
	#fi
	if [ "$name" = 'total' ]; then
		total_u=$size_u
	elif (($size > $CRITSIZE)) ;then
		critdirs+="$name ($size_u)  "
	elif (($size > $WARNSIZE)) ; then
		warndirs+="$name ($size_u)  "
	fi
done <<<"`du -chs $DIRS 2>$ERRORFILE`"
chown nagios $ERRORFILE

exitstatus=$STATE_OK
if [ -n "$critdirs" ] ; then
	echo "$critdirs"
	[ -n "$warndirs" ] && echo "warning: $warndirs"
	exitstatus=$STATE_CRITICAL
elif [ -n "$warndirs" ]; then
	echo "$warndirs"
	exitstatus=$STATE_WARNING
fi
if [ -s $ERRORFILE ]; then
	echo "'Errors: `cat $ERRORFILE`"
	exitstatus=$STATE_CRITICAL
fi
if [ $exitstatus = $STATE_OK ] ;then
	echo "all dirs ok (total: $total_u)"
fi

#rm -f $ERRORFILE
exit $exitstatus
